.. _monte_carlo_generators :

====================================================
Monte-Carlo sample generators
====================================================

This module contains classes and functions to sample training
structures using Monte-Carlo at an increasing series of temperatures,
given a specific supercell matrix and a constant composition or
chemical potentials.

Class are implemented with :class:`smol.moca`.

.. automodule:: WFacer.sample_generators.mc_generators
   :members:
   :undoc-members:
   :show-inheritance:
